==> apikit-scaffolder-1.0.5-sources.jar: org/mule/apikit/scaffolding/internal/mapper/APISyncResourceLoader.java <==
/*
 * Copyright © MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.apikit.scaffolding.internal.mapper;

import static java.lang.String.format;
import static java.lang.System.getProperty;
import static java.util.regex.Pattern.compile;

import amf.core.client.common.remote.Content;
import amf.core.client.platform.resource.ResourceLoader;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URLConnection;
import java.util.concurrent.CompletableFuture;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.commons.io.IOUtils;

public class APISyncResourceLoader implements ResourceLoader {

  private String rootResource;
  private static final String EXCHANGE_MODULES = "exchange_modules";
  private static final Pattern EXCHANGE_PATTERN = compile("exchange_modules/([^/]+)/([^/]+)/([^/]+)/(.*)");
  private static final String RESOURCE_FORMAT = "resource::%s:%s:%s:%s:%s:%s";
  private static final String RAML_FRAGMENT_CLASSIFIER = "raml-fragment";
  private static final String EXCHANGE_TYPE = "zip";
  private static final String protocol = "jar:file:";
  private static final String localRepository = getProperty("user.home") + "/.m2/repository";
  private static final String API_SYNC_PROTOCOL = "resource::";

  APISyncResourceLoader(String mainFile) {
    this.rootResource = mainFile.substring(0, mainFile.lastIndexOf(":") + 1);
  }

  @Override
  public CompletableFuture<Content> fetch(String resource) {
    CompletableFuture<Content> result = new CompletableFuture<>();
    try {
      if (resource == null) {
        result.completeExceptionally(new RuntimeException("Cannot resolve resource null"));
        return result;
      }

      URI resourceURI = apiSyncToURI(toApiSyncResource(resource));
      URLConnection connection = resourceURI.toURL().openConnection();
      connection.setUseCaches(false);
      String fileContent = IOUtils.toString(connection.getInputStream());
      result.complete(new Content(fileContent, resource));
      return result;
    } catch (Exception e) {
      result.completeExceptionally(e);
      return result;
    }
  }

  private String toApiSyncResource(String resource) {
    if (isAPISync(resource)) {
      return resource;
    }

    if (isExchangeModules(resource)) {
      return exchangeModuleToAPISync(resource);
    }

    return rootResource + resource;
  }

  private boolean isExchangeModules(String path) {
    return EXCHANGE_PATTERN.matcher(path).find();
  }

  private boolean isAPISync(String path) {
    return path.startsWith(API_SYNC_PROTOCOL);
  }

  private String exchangeModuleToAPISync(String resource) {
    String resourceToFetch = resource.substring(resource.lastIndexOf(EXCHANGE_MODULES));

    Matcher exchangeMatcher = EXCHANGE_PATTERN.matcher(resourceToFetch);

    if (!exchangeMatcher.find()) {
      return resource;
    }

    String groupId = exchangeMatcher.group(1);
    String artifactId = exchangeMatcher.group(2);
    String version = exchangeMatcher.group(3);
    String filePath = exchangeMatcher.group(4);
    return format(RESOURCE_FORMAT, groupId, artifactId, version, RAML_FRAGMENT_CLASSIFIER, EXCHANGE_TYPE, filePath);
  }

  private URI apiSyncToURI(String apiSync) throws URISyntaxException {
    String[] parts = apiSync.substring(API_SYNC_PROTOCOL.length()).split(":");

    String groupId = parts[0].replaceAll("\\.", "/");
    String artifact = parts[1];
    String version = parts[2];
    String classifier = parts[3];
    String file = parts[5];
    return new URI(format("%s%s/%s/%s/%s/%s-%s-%s.zip!/%s", protocol, localRepository, groupId, artifact, version,
                          artifact, version, classifier, file));
  }
}

==> apikit-scaffolder-1.0.6-sources.jar: org/mule/apikit/scaffolding/internal/mapper/APISyncResourceLoader.java <==
/*
 * Copyright © MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.apikit.scaffolding.internal.mapper;

import static java.lang.String.format;
import static java.lang.System.getProperty;
import static java.util.regex.Pattern.compile;

import amf.core.client.common.remote.Content;
import amf.core.client.platform.resource.ResourceLoader;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URLConnection;
import java.util.concurrent.CompletableFuture;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.commons.io.IOUtils;

public class APISyncResourceLoader implements ResourceLoader {

  private String rootResource;
  private static final String EXCHANGE_MODULES = "exchange_modules";
  private static final Pattern EXCHANGE_PATTERN = compile("exchange_modules/([^/]+)/([^/]+)/([^/]+)/(.*)");
  private static final String RESOURCE_FORMAT = "resource::%s:%s:%s:%s:%s:%s";
  private static final String RAML_FRAGMENT_CLASSIFIER = "raml-fragment";
  private static final String EXCHANGE_TYPE = "zip";
  private static final String protocol = "jar:file:";
  private static final String localRepository = getProperty("user.home").replaceAll("\\\\", "/") + "/.m2/repository";
  private static final String API_SYNC_PROTOCOL = "resource::";

  APISyncResourceLoader(String mainFile) {
    this.rootResource = mainFile.substring(0, mainFile.lastIndexOf(":") + 1);
  }

  @Override
  public CompletableFuture<Content> fetch(String resource) {
    CompletableFuture<Content> result = new CompletableFuture<>();
    try {
      if (resource == null) {
        result.completeExceptionally(new RuntimeException("Cannot resolve resource null"));
        return result;
      }

      URI resourceURI = apiSyncToURI(toApiSyncResource(resource));
      URLConnection connection = resourceURI.toURL().openConnection();
      connection.setUseCaches(false);
      String fileContent = IOUtils.toString(connection.getInputStream());
      result.complete(new Content(fileContent, resource));
      return result;
    } catch (Exception e) {
      result.completeExceptionally(e);
      return result;
    }
  }

  private String toApiSyncResource(String resource) {
    if (isAPISync(resource)) {
      return resource;
    }

    if (isExchangeModules(resource)) {
      return exchangeModuleToAPISync(resource);
    }

    return rootResource + resource;
  }

  private boolean isExchangeModules(String path) {
    return EXCHANGE_PATTERN.matcher(path).find();
  }

  private boolean isAPISync(String path) {
    return path.startsWith(API_SYNC_PROTOCOL);
  }

  private String exchangeModuleToAPISync(String resource) {
    String resourceToFetch = resource.substring(resource.lastIndexOf(EXCHANGE_MODULES));

    Matcher exchangeMatcher = EXCHANGE_PATTERN.matcher(resourceToFetch);

    if (!exchangeMatcher.find()) {
      return resource;
    }

    String groupId = exchangeMatcher.group(1);
    String artifactId = exchangeMatcher.group(2);
    String version = exchangeMatcher.group(3);
    String filePath = exchangeMatcher.group(4);
    return format(RESOURCE_FORMAT, groupId, artifactId, version, RAML_FRAGMENT_CLASSIFIER, EXCHANGE_TYPE, filePath);
  }

  private URI apiSyncToURI(String apiSync) throws URISyntaxException {
    String[] parts = apiSync.substring(API_SYNC_PROTOCOL.length()).split(":");

    String groupId = parts[0].replaceAll("\\.", "/");
    String artifact = parts[1];
    String version = parts[2];
    String classifier = parts[3];
    String file = parts[5];
    return new URI(format("%s%s/%s/%s/%s/%s-%s-%s.zip!/%s", protocol, localRepository, groupId, artifact, version,
                          artifact, version, classifier, file));
  }
}
